@@ -272,8 +272,11 @@ ffmpeg_trgt::init(ProgressCallback *cb=NULL)
 	// This covers the dumb cmd.exe behavior.
 	// See: http://eli.thegreenplace.net/2011/01/28/on-spaces-in-the-paths-of-programs-and-files-on-windows/
 	command = "\"" + command + "\"";
-
-	file=popen(command.c_str(),POPEN_BINARY_WRITE_TYPE);
+	
+	const wchar_t* wcommand = reinterpret_cast<const wchar_t*>(g_utf8_to_utf16(command.c_str(), -1, NULL, NULL, NULL));
+	const wchar_t* wmode = reinterpret_cast<const wchar_t*>(g_utf8_to_utf16(POPEN_BINARY_WRITE_TYPE, -1, NULL, NULL, NULL));
+	
+	file=_wpopen(wcommand, wmode);
 
 #elif defined(UNIX_PIPE_TO_PROCESSES)
 
@@ -384,7 +387,7 @@ ffmpeg_trgt::end_scanline()
 	if(!file)
 		return false;
 
-	convert_color_format(buffer, color_buffer, desc.get_w(), PF_RGB, gamma());
+	color_to_pixelformat(buffer, color_buffer, PF_RGB, 0, desc.get_w());
 
 	if(!fwrite(buffer,1,desc.get_w()*3,file))
 		return false;
