@@ -32,6 +32,11 @@
 #	include <config.h>
 #endif
 
+#include <synfig/localization.h>
+#include <synfig/general.h>
+#include <synfig/color.h>
+
+#include <glib/gstdio.h>
 #include <ETL/stringf>
 #include "trgt_gif.h"
 #include <cstdio>
@@ -58,8 +63,7 @@ SYNFIG_TARGET_SET_CVS_ID(gif,"$Id$");
 gif::gif(const char *filename_, const synfig::TargetParam & /* params */):
 	bs(),
 	filename(filename_),
-	file( (filename=="-")?stdout:fopen(filename_,POPEN_BINARY_WRITE_TYPE) ),
-	i(),
+	file( (filename=="-")?stdout:g_fopen(filename_,POPEN_BINARY_WRITE_TYPE) ),
 	codesize(),
 	rootsize(),
 	nextcode(),
@@ -103,7 +107,7 @@ gif::set_rend_desc(RendDesc *given_desc)
 }
 
 bool
-gif::init(synfig::ProgressCallback *cb)
+gif::init(synfig::ProgressCallback * /* cb */)
 {
 	int w=desc.get_w(),h=desc.get_h();
 
@@ -143,7 +147,7 @@ gif::init(synfig::ProgressCallback *cb)
 
 	if(!local_palette)
 	{
-		curr_palette=Palette::grayscale(256/(1<<(8-rootsize))-1);
+		curr_palette = Palette::grayscale(256/(1<<(8-rootsize))-1, 1);
 		output_curr_palette();
 	}
 
@@ -167,20 +171,13 @@ void
 gif::output_curr_palette()
 {
 	// Output the color table
-	for(i=0;i<256/(1<<(8-rootsize));i++)
-	{
-		if(i<(signed)curr_palette.size())
-		{
-			Color color(curr_palette[i].color.clamped());
-			//fputc(i*(1<<(8-rootsize)),file.get());
-			//fputc(i*(1<<(8-rootsize)),file.get());
-			//fputc(i*(1<<(8-rootsize)),file.get());
-			fputc(gamma().r_F32_to_U8(color.get_r()),file.get());
-			fputc(gamma().g_F32_to_U8(color.get_g()),file.get());
-			fputc(gamma().b_F32_to_U8(color.get_b()),file.get());
-		}
-		else
-		{
+	for(int i = 0; i < 256/(1<<(8-rootsize)); ++i) {
+		if (i < (int)curr_palette.size()) {
+			Color color = curr_palette[i].color.clamped();
+			fputc((unsigned char)(color.get_r()*255.99), file.get());
+			fputc((unsigned char)(color.get_g()*255.99), file.get());
+			fputc((unsigned char)(color.get_b()*255.99), file.get());
+		} else {
 			fputc(255,file.get());
 			fputc(0,file.get());
 			fputc(255,file.get());
@@ -211,10 +208,9 @@ gif::start_frame(synfig::ProgressCallback *callback)
 void
 gif::end_frame()
 {
-	int w=desc.get_w(),h=desc.get_h(),i;
+	int w = desc.get_w(), h = desc.get_h();
 	unsigned int value;
-	int
-		delaytime=round_to_int(100.0/desc.get_frame_rate());
+	int delaytime = round_to_int(100.0/desc.get_frame_rate());
 
 	bool build_off_previous(multi_image);
 
@@ -241,12 +237,12 @@ gif::end_frame()
 
 	if(local_palette)
 	{
-		curr_palette=Palette(curr_surface,256/(1<<(8-rootsize))-build_off_previous-1);
+		curr_palette = Palette(curr_surface, 256/(1<<(8-rootsize)) - build_off_previous - 1, Gamma());
 		synfig::info("curr_palette.size()=%d",curr_palette.size());
 	}
 
-	int transparent_index(curr_palette.find_closest(Color(1,0,1,0))-curr_palette.begin());
-	bool has_transparency(curr_palette[transparent_index].color.get_a()<=0.00001);
+	int transparent_index = curr_palette.find_closest(Color(1,0,1,0), Gamma()) - curr_palette.begin();
+	bool has_transparency = curr_palette[transparent_index].color.get_a()<=0.00001;
 
 	if(has_transparency)
 		build_off_previous=false;
@@ -321,13 +317,13 @@ gif::end_frame()
 
 	for(int cur_scanline=0;cur_scanline<desc.get_h();cur_scanline++)
 	{
-		//convert_color_format(curr_frame[cur_scanline], curr_surface[cur_scanline], desc.get_w(), PF_GRAY, gamma());
+		//color_to_pixelformat(curr_frame[cur_scanline], curr_surface[cur_scanline], PF_GRAY, &gamma(), desc.get_w());
 
 		// Now we compress it!
-		for(i=0;i<w;i++)
+		for(int i=0; i < w; ++i)
 		{
 			Color color(curr_surface[cur_scanline][i].clamped());
-			Palette::iterator iter(curr_palette.find_closest(color));
+			Palette::iterator iter(curr_palette.find_closest(color, Gamma()));
 
 			if(dithering)
 			{
