@@ -73,6 +73,9 @@ public:
 
 	//! Sets the context to the Time \time. It is done recursively.
 	void set_time(Time time, bool force = false) const;
+	
+	//! Loads resources (frames from external files) for Time \time. It is done recursively.
+	void load_resources(Time time, bool force = false) const;
 
 	//! Sets the context outline grow to \outline_grow. It is done recursively.
 	void set_outline_grow(Real outline_grow) const;
@@ -92,7 +95,7 @@ public:
 	Real z_range_position;
 	//! Defines the depth of the range of the Z_Depth visibility
 	Real z_range_depth;
-	//! Layers with z_Depth inside transition are partially visibile
+	//! Layers with z_Depth inside transition are partially visible
 	Real z_range_blur;
 
 	explicit ContextParams(bool render_excluded_contexts = false):
@@ -133,10 +136,16 @@ public:
 		IndependentContext(x), params(context.params) { }
 
 	//! Returns next iterator.
-	Context get_next()const { return Context(*this+1, params); }
+	Context get_next() const {
+		IndependentContext c(*this);
+		return Context(++c, params);
+	}
 
 	//! Returns previous iterator.
-	Context get_previous()const { return Context(*this-1, params); }
+	Context get_previous() const {
+		IndependentContext c(*this);
+		return Context(--c, params);
+	}
 
 	//! Get rendering parameters.
 	const ContextParams& get_params()const { return params; }
@@ -161,9 +170,6 @@ public:
 	//! Returns the first context's layer's handle that intesects the given \point */
 	etl::handle<Layer> hit_check(const Point &point)const;
 
-	// Set Render Method. Passes the information of the render method to use to the layers
-	void set_render_method(RenderMethod x);
-
 	//! Returns \c true if layer is active with this context_params
 	static inline bool active(const ContextParams &context_params, const Layer &layer) {
 		return layer.active()
