@@ -45,7 +45,6 @@
 #include <synfig/value.h>
 #include <synfig/valuenode.h>
 
-#include <synfig/rendering/common/task/tasksurfaceempty.h>
 #include <synfig/rendering/common/task/taskblend.h>
 
 #endif
@@ -122,7 +121,7 @@ Layer_Duplicate::get_color(Context context, const Point &pos)const
 	float amount(get_amount());
 	Color color;
 
-	Mutex::Lock lock(mutex);
+	std::lock_guard<std::mutex> lock(mutex);
 	Time time_cur = get_time_mark();
 	duplicate_param->reset_index(time_cur);
 	do
@@ -188,7 +187,7 @@ Layer_Duplicate::accelerated_render(Context context,Surface *surface,int quality
 	Time time_cur = get_time_mark();
 	int steps = duplicate_param->count_steps(time_cur);
 
-	Mutex::Lock lock(mutex);
+	std::lock_guard<std::mutex> lock(mutex);
 	duplicate_param->reset_index(time_cur);
 	do
 	{
@@ -234,7 +233,7 @@ Layer_Duplicate::accelerated_cairorender(Context context, cairo_t *cr, int quali
 	Time time_cur = get_time_mark();
 	int steps = duplicate_param->count_steps(time_cur);
 	
-	Mutex::Lock lock(mutex);
+	std::lock_guard<std::mutex> lock(mutex);
 	duplicate_param->reset_index(time_cur);
 	cairo_save(cr);
 	do
@@ -268,9 +267,9 @@ Layer_Duplicate::build_rendering_task_vfunc(Context context) const
 	ColorReal amount = get_amount() * Context::z_depth_visibility(context.get_params(), *this);
 	Color::BlendMethod blend_method = get_blend_method();
 
-	rendering::Task::Handle task = new rendering::TaskSurfaceEmpty();
+	rendering::Task::Handle task;
 
-	Mutex::Lock lock(mutex);
+	std::lock_guard<std::mutex> lock(mutex);
 	duplicate_param->reset_index(time_cur);
 	do
 	{
