@@ -286,6 +286,12 @@ public:
 class synfig::ValueNode_AnimatedInterfaceConst::Internal {
 public:
 	template<typename T>
+	static T pass(const T &x) { return x; }
+	
+	static int int_premult(const int &x) { return x*(3*256); }
+	static int int_demult(const int &x) { return (x + 3*128)/(3*256); }
+	
+	template< typename T, T premult(const T&) = pass<T>, T demult(const T&)  = pass<T> >
 	class Hermite: public Interpolator
 	{
 	public:
@@ -303,8 +309,8 @@ public:
 			is_angle_type<value_type> is_angle;
 			subtractor<value_type> subtract_func;
 
-			mutable hermite<Time, Time> first;
-			mutable hermite<value_type, Time> second;
+			mutable etl::hermite<Time, Time> first;
+			mutable etl::hermite<value_type, Time> second;
 			WaypointList::iterator start;
 			WaypointList::iterator end;
 
@@ -330,7 +336,7 @@ public:
 					second.sync();
 				}
 
-				return second(first(t));
+				return demult(second(first(t)));
 			}
 		}; // END of struct PathSegment
 
@@ -348,7 +354,7 @@ public:
 
 		virtual WaypointList::iterator new_waypoint(Time t, ValueBase value)
 		{
-			try { animated.find(t); throw Exception::BadTime(_("A waypoint already exists at this point in time")); } catch(Exception::NotFound) { };
+			try { animated.find(t); throw Exception::BadTime(_("A waypoint already exists at this point in time")); } catch(Exception::NotFound&) { };
 			Waypoint waypoint(value, t);
 			waypoint.set_parent_value_node(&animated.node());
 
@@ -369,7 +375,7 @@ public:
 
 		virtual WaypointList::iterator new_waypoint(Time t, ValueNode::Handle value_node)
 		{
-			try { animated.find(t); throw Exception::BadTime(_("A waypoint already exists at this point in time")); } catch(Exception::NotFound) { };
+			try { animated.find(t); throw Exception::BadTime(_("A waypoint already exists at this point in time")); } catch(Exception::NotFound&) { };
 
 			Waypoint waypoint(value_node,t);
 			waypoint.set_parent_value_node(&animated.node());
@@ -403,10 +409,9 @@ public:
 
 			curve_list.clear();
 
-			WaypointList::iterator prev,iter,next=animated.waypoint_list_.begin();
-			int i=0;
+			WaypointList::iterator iter,next=animated.waypoint_list_.begin();
 			// The curve list must be calculated because we sorted the waypoints.
-			for(iter=next++;iter!=animated.waypoint_list_.end() && next!=animated.waypoint_list_.end();prev=iter,iter=next++,i++)
+			for(iter=next++;iter!=animated.waypoint_list_.end() && next!=animated.waypoint_list_.end(); iter=next++)
 			{
 				typename curve_list_type::value_type curve;
 				WaypointList::iterator after_next(next);
@@ -631,6 +636,12 @@ public:
 
 
 				curve.first.sync();
+				
+				// for proper integer interpolation
+				curve.second.p1() = premult( curve.second.p1() );
+				curve.second.p2() = premult( curve.second.p2() );
+				curve.second.t1() = premult( curve.second.t1() );
+				curve.second.t2() = premult( curve.second.t2() );
 				curve.second.sync();
 
 				curve_list.push_back(curve);
@@ -684,7 +695,7 @@ public:
 			// Make sure we are getting data of the correct type
 			//if(data.type!=type)
 			//	return waypoint_list_type::iterator();
-			try { animated.find(t); throw Exception::BadTime(_("A waypoint already exists at this point in time")); } catch(Exception::NotFound) { };
+			try { animated.find(t); throw Exception::BadTime(_("A waypoint already exists at this point in time")); } catch(Exception::NotFound&) { };
 
 			Waypoint waypoint(value,t);
 			waypoint.set_parent_value_node(&animated.node());
@@ -702,7 +713,7 @@ public:
 			// Make sure we are getting data of the correct type
 			//if(data.type!=type)
 			//	return waypoint_list_type::iterator();
-			try { animated.find(t); throw Exception::BadTime(_("A waypoint already exists at this point in time")); } catch(Exception::NotFound) { };
+			try { animated.find(t); throw Exception::BadTime(_("A waypoint already exists at this point in time")); } catch(Exception::NotFound&) { };
 
 			Waypoint waypoint(value_node,t);
 			waypoint.set_parent_value_node(&animated.node());
@@ -774,7 +785,7 @@ public:
 			// Make sure we are getting data of the correct type
 			//if(data.type!=type)
 			//	return waypoint_list_type::iterator();
-			try { animated.find(t); throw Exception::BadTime(_("A waypoint already exists at this point in time")); } catch(Exception::NotFound) { };
+			try { animated.find(t); throw Exception::BadTime(_("A waypoint already exists at this point in time")); } catch(Exception::NotFound&) { };
 
 
 			Waypoint waypoint(value,t);
@@ -793,7 +804,7 @@ public:
 			// Make sure we are getting data of the correct type
 			//if(data.type!=type)
 			//	return waypoint_list_type::iterator();
-			try { animated.find(t); throw Exception::BadTime(_("A waypoint already exists at this point in time")); } catch(Exception::NotFound) { };
+			try { animated.find(t); throw Exception::BadTime(_("A waypoint already exists at this point in time")); } catch(Exception::NotFound&) { };
 
 			Waypoint waypoint(value_node,t);
 			waypoint.set_parent_value_node(&animated.node());
@@ -1099,8 +1110,6 @@ ValueNode_AnimatedInterfaceConst::waypoint_is_only_use_of_valuenode(Waypoint &wa
 void
 ValueNode_AnimatedInterfaceConst::erase(const UniqueID &x)
 {
-	// \todo printf?
-	printf("%s:%d erasing waypoint from %lx\n", __FILE__, __LINE__, uintptr_t(this));
 	WaypointList::iterator iter(find(x));
 	Waypoint waypoint(*iter);
 	assert(waypoint.get_value_node());
@@ -1153,10 +1162,10 @@ ValueNode_AnimatedInterfaceConst::set_type(Type &t)
 		interpolator_ = new Internal::Hermite<Time>(*this);
 	else
 	if (t == type_real)
-		interpolator_ = new Internal::Hermite<Vector::value_type>(*this);
+		interpolator_ = new Internal::Hermite<Real>(*this);
 	else
 	if (t == type_integer)
-		interpolator_ = new Internal::Hermite<int>(*this);
+		interpolator_ = new Internal::Hermite<int, Internal::int_premult, Internal::int_demult>(*this);
 	else
 	if (t == type_angle)
 		interpolator_ = new Internal::Hermite<Angle>(*this);
@@ -1272,7 +1281,7 @@ ValueNode_AnimatedInterfaceConst::insert_time(const Time& location, const Time&
 		}
 		animated_changed();
 	}
-	catch(Exception::NotFound) { }
+	catch(Exception::NotFound&) { }
 }
 
 void
