@@ -37,6 +37,7 @@
 #include "valuenode_composite.h"
 #include <synfig/general.h>
 #include <synfig/localization.h>
+#include <synfig/valuenode_registry.h>
 #include <synfig/exception.h>
 #include <ETL/hermite>
 
@@ -53,6 +54,8 @@ using namespace synfig;
 
 /* === G L O B A L S ======================================================= */
 
+REGISTER_VALUENODE(ValueNode_BLineCalcVertex, RELEASE_VERSION_0_61_07, "blinecalcvertex", "Spline Vertex")
+
 /* === P R O C E D U R E S ================================================= */
 
 /* === M E T H O D S ======================================================= */
@@ -95,64 +98,35 @@ ValueNode_BLineCalcVertex::operator()(Time t)const
 	if (getenv("SYNFIG_DEBUG_VALUENODE_OPERATORS"))
 		printf("%s:%d operator()\n", __FILE__, __LINE__);
 
-	const std::vector<ValueBase> bline((*bline_)(t).get_list());
+	const ValueBase::List bline = (*bline_)(t).get_list();
 	handle<ValueNode_BLine> bline_value_node( handle<ValueNode_BLine>::cast_dynamic(bline_) );
 	assert(bline_value_node);
 
-	const bool looped(bline_value_node->get_loop());
-	int size = bline.size(), from_vertex;
-	bool loop((*loop_)(t).get(bool()));
-	bool homogeneous((*homogeneous_)(t).get(bool()));
-	Real amount((*amount_)(t).get(Real()));
-	if(homogeneous)
-	{
-		amount=hom_to_std(bline, amount, loop, looped);
-	}
-	BLinePoint blinepoint0, blinepoint1;
+	const bool looped = bline_value_node->get_loop();
+	int size = (int)bline.size();
+	int count = looped ? size : size - 1;
+	if (count < 1) return Vector();
 
-	if (!looped) size--;
-	if (size < 1) return Vector();
-	if (loop)
-	{
-		amount = amount - int(amount);
-		if (amount < 0) amount++;
-	}
-	else
-	{
-		if (amount < 0) amount = 0;
-		if (amount > 1) amount = 1;
-	}
+	bool loop = (*loop_)(t).get(bool());
+	bool homogeneous = (*homogeneous_)(t).get(bool());
+	Real amount = (*amount_)(t).get(Real());
 
-	vector<ValueBase>::const_iterator iter, next(bline.begin());
+	if (loop) amount -= floor(amount);
+	if (homogeneous) amount = hom_to_std(bline, amount, loop, looped);
+	if (amount < 0) amount = 0;
+	if (amount > 1) amount = 1;
+	amount *= count;
 
-	iter = looped ? --bline.end() : next++;
-	amount = amount * size;
-	from_vertex = int(amount);
-	if (from_vertex > size-1) from_vertex = size-1;
-	blinepoint0 = from_vertex ? (next+from_vertex-1)->get(BLinePoint()) : iter->get(BLinePoint());
-	blinepoint1 = (next+from_vertex)->get(BLinePoint());
+	int i0 = std::max(0, std::min(size-1, (int)floor(amount)));
+	int i1 = (i0 + 1) % size;
+	Real part = amount - i0;
+
+	const BLinePoint &blinepoint0 = bline[i0].get(BLinePoint());
+	const BLinePoint &blinepoint1 = bline[i1].get(BLinePoint());
 
 	etl::hermite<Vector> curve(blinepoint0.get_vertex(),   blinepoint1.get_vertex(),
 							   blinepoint0.get_tangent2(), blinepoint1.get_tangent1());
-	return curve(amount-from_vertex);
-}
-
-
-
-
-
-
-
-String
-ValueNode_BLineCalcVertex::get_name()const
-{
-	return "blinecalcvertex";
-}
-
-String
-ValueNode_BLineCalcVertex::get_local_name()const
-{
-	return _("Spline Vertex");
+	return curve(part);
 }
 
 bool
